@extends('backend.layout')

@section('content')
  <div class="page-header">
    <h4 class="page-title">{{ __('Blogs') }}</h4>
    <ul class="breadcrumbs">
      <li class="nav-home">
        <a href="{{route('admin.dashboard')}}">
          <i class="flaticon-home"></i>
        </a>
      </li>
      <li class="separator">
        <i class="flaticon-right-arrow"></i>
      </li>
      <li class="nav-item">
        <a href="#">{{ __('Blogs Management') }}</a>
      </li>
      <li class="separator">
        <i class="flaticon-right-arrow"></i>
      </li>
      <li class="nav-item">
        <a href="#">{{ __('Blogs') }}</a>
      </li>
    </ul>
  </div>

  <div class="row">
    <div class="col-md-12">
      <div class="card">
        <div class="card-header">
          <div class="row">
            <div class="col-lg-4">
              <div class="card-title d-inline-block">{{ __('Blogs') }}</div>
            </div>

            <div class="col-lg-4 offset-lg-4 mt-2 mt-lg-0">
              <a
                href="{{ route('admin.blogs_management.create_blog') }}"
                class="btn btn-primary btn-sm float-right"
              ><i class="fas fa-plus"></i> {{ __('Add Blog') }}</a>

              <button
                class="btn btn-danger btn-sm float-right mr-2 d-none bulk-delete"
                data-href="{{ route('admin.blogs_management.bulk_delete_blog') }}"
              ><i class="flaticon-interface-5"></i> {{ __('Delete') }}</button>
            </div>
          </div>
        </div>

        <div class="card-body">
          <div class="row">
            <div class="col-lg-12">
              @if (count($blogContents) == 0)
                <h3 class="text-center">{{ __('NO BLOG FOUND!') }}</h3>
              @else
                <div class="table-responsive">
                  <table class="table table-striped mt-3" id="basic-datatables">
                    <thead>
                      <tr>
                        <th scope="col">
                          <input type="checkbox" class="bulk-check" data-val="all">
                        </th>
                        <th scope="col">{{ __('Title') }}</th>
                        <th scope="col">{{ __('Category') }}</th>
                        <th scope="col">{{ __('Publish Date') }}</th>
                        <th scope="col">{{ __('Serial Number') }}</th>
                        <th scope="col">{{ __('Actions') }}</th>
                      </tr>
                    </thead>
                    <tbody>
                      @foreach ($blogContents as $blogContent)
                        <tr>
                          <td>
                            <input type="checkbox" class="bulk-check" data-val="{{ $blogContent->blog_id }}">
                          </td>
                          <td>
                            {{strlen($blogContent->title) > 30 ? mb_substr($blogContent->title,0,30,'utf-8') . '...' : $blogContent->title}}
                          </td>
                          <td>{{ $blogContent->blogCategory->name }}</td>
                          <td>
                            @php
                              // first, convert the string into date
                              $date = Carbon\Carbon::parse($blogContent->blog->created_at);
                            @endphp
                            {{ date_format($date, 'M d, Y') }}
                          </td>
                          <td>{{ $blogContent->blog->serial_number }}</td>
                          <td>
                            <a
                              class="btn btn-secondary btn-sm mr-1"
                              href="{{ route('admin.blogs_management.edit_blog', $blogContent->blog_id) }}"
                            >
                                <i class="fas fa-edit"></i>
                            </a>

                            <form
                              class="deleteForm d-inline-block"
                              action="{{ route('admin.blogs_management.delete_blog') }}"
                              method="post"
                            >
                              @csrf
                              <input type="hidden" name="blog_id" value="{{ $blogContent->blog_id }}">
                              <button type="submit" class="btn btn-danger btn-sm deleteBtn">
                                  <i class="fas fa-trash"></i>
                              </button>
                            </form>
                          </td>
                        </tr>
                      @endforeach
                    </tbody>
                  </table>
                </div>
              @endif
            </div>
          </div>
        </div>


      </div>
    </div>
  </div>
@endsection
